@@ -1,7 +1,11 @@
 # Huber M-estimator of the weighted mean
-weighted_mean_huber <- function(x, w, k, type = "rhj", asym = FALSE,
+weighted_mean_huber <- function(x, w, k, type = "rwm", asym = FALSE,
     info = FALSE, na.rm = FALSE, verbose = TRUE, ...)
 {
+    type <- match.arg(type, c("rht", "rhj", "rwm"))
+    if (type == "rhj")
+        type <- "rwm"
+
     string <- paste0("Huber M-estimator (type = ", type, ifelse(asym,
         "; asym. psi", ""), ")")
     psi <- ifelse(asym, 1, 0)
@@ -22,22 +26,14 @@ weighted_mean_huber <- function(x, w, k, type = "rhj", asym = FALSE,
     }
     # otherwise
     if (type == "rwm") {
-        warning("The 'rwm' argument is deprecated; please use 'rhj' instead",
-            call. = FALSE)
-        type <- "rhj"
-    }
-    # select method
-    if (type == "rhj") {
         res <- robsvyreg(rep(1, dat$n), dat$x, dat$w, k, psi, 0, NULL, NULL,
             verbose, ...)
-    } else if (type == "rht") {
+    }
+    if (type == "rht") {
         xvar <- mean(dat$w) / dat$w
         res <- robsvyreg(xvar, dat$x, dat$w, k, psi, 0, NULL, xvar, verbose,
             ...)
-    } else {
-        stop(paste0("Method '", type, "' does not exist\n"), call. = FALSE)
     }
-
     # check for failure of convergence
     if (!res$optim$converged) {
         res$estimate <- NA
@@ -46,7 +42,7 @@ weighted_mean_huber <- function(x, w, k, type = "rhj", asym = FALSE,
     # return
     if (info) {
         res$model[c("n", "p")] <- NULL
-        if (type == "rhj")
+        if (type == "rwm")
             res$model$x <- NULL
         res$characteristic <- "mean"
         res$estimator$string <- string
@@ -58,7 +54,7 @@ weighted_mean_huber <- function(x, w, k, type = "rhj", asym = FALSE,
     }
 }
 # Huber M-estimator of the weighted total
-weighted_total_huber <- function(x, w, k, type = "rhj", asym = FALSE,
+weighted_total_huber <- function(x, w, k, type = "rwm", asym = FALSE,
     info = FALSE, na.rm = FALSE, verbose = TRUE, ...)
 {
     res <- weighted_mean_huber(x, w, k, type, asym, info, na.rm, verbose, ...)
