@@ -4,6 +4,6 @@
 
 #ifndef _HUBER2_H
 #define _HUBER2_H
-void huberm(double* restrict, double* restrict, double* restrict, double*,
+void whuber2(double* restrict, double* restrict, double* restrict, double*,
     double*, double*, int*, int*, const double*, int*, int*);
 #endif
