@@ -28,25 +28,6 @@
 // will silently eliminate the trailing comma) is not portable (clang complains)
 #define PRINT_OUT(...) Rprintf(__VA_ARGS__)
 
-// structure: regression data
-typedef struct regdata_struct {
-    int n;
-    int p;
-    double *x;
-    double *y;
-    double *w;
-    double *xwgt;
-} regdata;
-
-// structure: work arrays
-typedef struct workarray_struct {
-    int lwork;
-    double *work_lapack;
-    double *work_x;
-    double *work_y;
-    double *work_2n;
-} workarray;
-
 // declaration
 robsurvey_error_type variance_est(regdata*, double*restrict, double* restrict,
     double*, double*, double*, double (*)(double, const double));
@@ -439,7 +420,7 @@ robsurvey_error_type inverse_qr(workarray *work, double* restrict x, int *n,
 }
 
 /******************************************************************************\
-|* design-based estimate of the regression covariance matrix                  *|
+|* Design-based estimate of the regression covariance matrix                  *|
 |*                                                                            *|
 |* x      model design matrix, array[n, p]                                    *|
 |* w      weights, array[n]                                                   *|
